package com.tanpu.fund.api;

import com.tanpu.common.model.Page;
import com.tanpu.common.model.Pageable;
import com.tanpu.common.model.adm.req.IfaNetImportReq;
import com.tanpu.common.model.fund.req.FundRankReq;
import com.tanpu.common.model.fund.resq.FundRankResp;
import com.tanpu.common.model.privatefund.resp.FundNavMessage;
import com.tanpu.common.model.product.req.NetReq;
import com.tanpu.common.model.product.req.ProductInfoReq;
import com.tanpu.common.model.product.req.ProductListReq;
import com.tanpu.common.model.product.resp.*;
import com.tanpu.common.model.tanpuroom.Type;
import com.tanpu.common.resp.CommonResp;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

@Api(tags = "产品服务")
public interface ProductApi {

    /**
     * /sys/constant tamp_user 中的接口
     * 策略需要维护到sys_constant中
     */
    @ApiOperation("根据条件获取探普产品信息")
    @PostMapping("/get/product/info")
    CommonResp<Page<ProductInfoVO>> getProductInfo(@ApiParam("筛选条件对象") @RequestBody ProductInfoReq req);

    @ApiOperation("获取产品详情")
    @GetMapping("/product/detail")
    CommonResp<ProductInfoVO> getProductDetailInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("获取产品详情")
    @GetMapping("/product/list")
    CommonResp<List<ProductInfoVO>> getProductList(@ApiParam("产品id") @RequestParam("ids") List<String> ids);

    @ApiOperation("单位净值")
    @GetMapping("/unit/net")
    CommonResp<UnitNetVO> getUnitNetInfo(@ApiParam("产品id") @RequestParam("id") String id, @ApiParam("对比基金id") @RequestParam(value = "ratioId", required = false) String ratioId,
                                         @ApiParam("查询时间段 1:近1个月 2:近3个月 3:近6个月 4:近1年 99:成立以来") @RequestParam("type") String type);

    @ApiOperation("收益走势")
    @GetMapping("/profit/trend")
    CommonResp<UnitNetVO> getProfitTrend(@ApiParam("产品id") @RequestParam("id") String id, @ApiParam("对比基金id") @RequestParam(value = "ratioId", required = false) String ratioId,
                                         @ApiParam("查询时间段 1:近1个月 2:近3个月 3:近6个月 4:近1年 98:自定义 99:成立以来") @RequestParam("type") String type,
                                         @ApiParam("开始时间") @RequestParam(value = "beginTime", required = false) Long beginTime,
                                         @ApiParam("开始时间") @RequestParam(value = "endTime", required = false) Long endTime);

    @ApiOperation("净值列表查询")
    @PostMapping("/get/net/list")
    CommonResp<Page<NetVO>> getNetListInfo(@ApiParam("净值列表筛选对象") @RequestBody NetReq req);

    @ApiOperation("分红配送")
    @GetMapping("/bonus/ratio")
    CommonResp<List<BonusRatioVO>> getBonusRatioInfo(@ApiParam("产品id") @RequestParam("id") String id);


    @ApiOperation("历史业绩")
    @GetMapping("/track/record")
    CommonResp<List<TrackRecordVO>> getTrackRecordInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("历史业绩 对比指数")
    @GetMapping("/track/recor/index")
    CommonResp<List<TrackRecordVO>> getTrackRecordInfoIndex(@ApiParam("对比指数ID") @RequestParam("indexId") String indexId);

    @ApiOperation("历史净值")
    @GetMapping("/track/net")
    CommonResp<Page<TrackNetVO>> getTrackNetListInfo(@ApiParam("产品id") @RequestParam("id") String id, @ApiParam("分页对象") Pageable page);

    @ApiOperation("风险评估")
    @GetMapping("/get/risk/rating")
    CommonResp<List<RiskRatingVO>> getRiskRatingInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("基金经理")
    @GetMapping("/fund/manager")
    CommonResp<List<FundManagerVO>> getFundManagerInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("基金档案")
    @GetMapping("/fund/record")
    CommonResp<FundRecordVO> getFundRecordInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("基金公司")
    @GetMapping("/fund/company")
    CommonResp<FundCompanyVO> getFundCompanyInfo(@ApiParam("基金公司id") @RequestParam("id") String id);

    @ApiOperation("根据条件获取探普产品信息")
    @PostMapping("/get/product/list")
    CommonResp<List<ProductInfoVO>> getProductInfolist(@ApiParam("筛选条件对象") @RequestBody ProductListReq req);

    @ApiOperation("动态回撤")
    @GetMapping("/dynamic/retreat")
    CommonResp<DynamicRetreatVO> getDynamicRetreatInfo(@RequestParam("id") String id);

    @ApiOperation("获取产品列表（只返回产品名称）")
    @GetMapping("/get/fund/info/simple")
    CommonResp<List<Type>> getSimpleFundList(@RequestParam("list") List<String> list);

    //**********************************************************私有基金start**********************************************************
    @ApiOperation("私有基金详情 - 私有基金")
    @GetMapping("/privatefund/detail")
    CommonResp<ProductInfoVO> getPrivateDetail(@RequestParam("id") String id);

    @ApiOperation("私有基金历史业绩 - 私有基金")
    @GetMapping("/privatefund/historyprofit")
    CommonResp<List<TrackRecordVO>> getHistoryprofit(@RequestParam("id") String id);

    @ApiOperation("历史净值 - 私有基金")
    @GetMapping("/privatefund/track/net")
    CommonResp<Page<TrackNetVO>> getPrivateFundTrackNetListInfo(@ApiParam("产品id") @RequestParam("id") String id, @ApiParam("分页对象") Pageable page);

    @ApiOperation("风险评估 - 私有基金")
    @GetMapping("/privatefund/get/risk/rating")
    CommonResp<List<RiskRatingVO>> getPrivateFundRiskRatingInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("获取私募产品 - 私有基金")
    @GetMapping("/privatefund/list")
    CommonResp<List<ProductInfoVO>> getPrivateFundList(@ApiParam("产品id") @RequestParam("ids") List<String> ids);

    @ApiOperation("推荐基金 - 私有基金")
    @GetMapping("/privatefund/query/samefund")
    CommonResp<List<FundSameResp>> getRemmendPrivateFundList(@RequestParam("fundId") String fundId);

    @ApiOperation(value = "根据Id查询私有产品基本信息 - 私有基金")
    @PostMapping(value = "/privateFundInfo/simpleList", produces = {"application/json"})
    CommonResp<List<FundInfoSimpleListResp>> privateSimpleList(@RequestBody List<String> idList);

    @ApiOperation("基金公司 - 私有基金")
    @GetMapping("/private/fund/company")
    CommonResp<FundCompanyVO> getPrivateFundCompanyInfo(@ApiParam("基金公司id") @RequestParam("id") String id,
                                                        @ApiParam(value = "理财师id") @RequestParam(required = false) String ifaId,
                                                        @ApiParam("分页对象") Pageable page);

    @ApiOperation("基金经理 - 私有基金")
    @GetMapping("/private/fund/manager")
    CommonResp<List<FundManagerVO>> getPrivateFundManagerInfo(@ApiParam("产品id") @RequestParam("id") String id,
                                                              @ApiParam("理财师id") @RequestParam(value = "ifaId", required = false) String ifaId);

    @ApiOperation("分红配送 - 私有基金")
    @GetMapping("/private/bonus/ratio")
    CommonResp<List<BonusRatioVO>> getPrivateBonusRatioInfo(@ApiParam("产品id") @RequestParam("id") String id);

    @ApiOperation("获取产品列表（只返回产品名称）")
    @GetMapping("/private/get/fund/info/simple")
    CommonResp<List<Type>> getSimplePrivateFundList(@RequestParam("list") List<String> list);

    //**********************************************************私有基金 end**********************************************************

    @ApiOperation(value = "根据Id查询私募产品基本信息")
    @PostMapping(value = "/fundInfo/simpleList", produces = {"application/json"})
    CommonResp<List<FundInfoSimpleListResp>> simpleList(@RequestBody List<String> idList);

    @ApiOperation("对比指数")
    @GetMapping("/fund/indexes")
    CommonResp<List<FundIndexBasicResp>> fundIndexes();

    @ApiOperation("查询同类基金")
    @GetMapping("/query/samefund")
    CommonResp<List<FundSameResp>> querySamefund(@RequestParam("fundId") String fundId);

    @ApiOperation("理财师净值导入")
    @GetMapping("/ifa/net/import")
    CommonResp<List<FundNavMessage>> importNetInfo(@RequestParam("file") MultipartFile file,
                                                   @RequestParam("fundId") @Valid @NotEmpty(message = "请先确定需要导入的基金") String fundId);

    @ApiOperation("理财师净值导入")
    @PostMapping("/ifa/net/import/check/save")
    CommonResp<List<FundNavMessage>> importNetCheckSaveInfo(@RequestBody @Valid @NotEmpty(message = "请确定需要修改的信息") IfaNetImportReq req);

    @ApiOperation("私募排行")
    @PostMapping("/private/rank")
    CommonResp<Page<FundRankResp>> getFundRankInfo(@RequestBody FundRankReq req);

    @ApiOperation("私募排行统计")
    @PostMapping("/private/rank/count")
    CommonResp<Long> getFundRankCountInfo(@RequestBody FundRankReq req);
}
