package com.tanpu.fund.controller;

import com.tanpu.common.auth.mapping.TanpuInterfaceLoginAuth;
import com.tanpu.common.model.Page;
import com.tanpu.common.model.Pageable;
import com.tanpu.common.model.adm.req.IfaNetImportReq;
import com.tanpu.common.model.fund.req.FundRankReq;
import com.tanpu.common.model.fund.resq.FundRankResp;
import com.tanpu.common.model.privatefund.resp.FundNavMessage;
import com.tanpu.common.model.product.req.NetReq;
import com.tanpu.common.model.product.req.ProductInfoReq;
import com.tanpu.common.model.product.req.ProductListReq;
import com.tanpu.common.model.product.resp.*;
import com.tanpu.common.model.tanpuroom.Type;
import com.tanpu.common.resp.CommonResp;
import com.tanpu.fund.api.ProductApi;
import com.tanpu.fund.feign.publicfund.FeignClientForPublicfund;
import com.tanpu.fund.service.ProductPrivateService;
import com.tanpu.fund.service.ProductService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Slf4j
public class ProductController implements ProductApi {

    @Resource
    private ProductService productService;
    @Resource
    private FeignClientForPublicfund feignClientForPublicfund;

    @Resource
    private ProductPrivateService productPrivateService;

    @Override
    public CommonResp<Page<ProductInfoVO>> getProductInfo(ProductInfoReq req) {
        return CommonResp.success(this.productService.getProductList(req));
    }

    @Override
    public CommonResp<ProductInfoVO> getProductDetailInfo(String id) {
        return CommonResp.success(this.productService.getProductDetail(id));
    }

    @Override
    public CommonResp<List<ProductInfoVO>> getProductList(List<String> ids) {
        return CommonResp.success(this.productService.getProductList(ids));
    }

    @Override
    public CommonResp<UnitNetVO> getUnitNetInfo(String id, String ratioId, String type) {
        return CommonResp.success(this.productService.getUnitNet(id, ratioId, type));
    }

    @Override
    public CommonResp<UnitNetVO> getProfitTrend(String id, String ratioId, String type, Long beginTime, Long endTime) {
        return CommonResp.success(this.productService.getProfitTrend(id, ratioId, type, beginTime, endTime));
    }

    @Override
    public CommonResp<Page<NetVO>> getNetListInfo(NetReq req) {
        return CommonResp.success(this.productService.getNetList(req));
    }

    @Override
    public CommonResp<List<BonusRatioVO>> getBonusRatioInfo(String id) {
        return CommonResp.success(this.productService.getBonusRatio(id));
    }

    @Override
    public CommonResp<List<TrackRecordVO>> getTrackRecordInfo(String id) {
        return CommonResp.success(this.productService.getTrackRecord(id));
    }

    @Override
    public CommonResp<List<TrackRecordVO>> getTrackRecordInfoIndex(String indexId) {
        return feignClientForPublicfund.getTrackRecordInfoIndex(indexId);
    }

    @Override
    public CommonResp<Page<TrackNetVO>> getTrackNetListInfo(String id, Pageable page) {
        return CommonResp.success(this.productService.getTrackNetList(id, page));
    }

    @Override
    public CommonResp<List<RiskRatingVO>> getRiskRatingInfo(String id) {
        return CommonResp.success(this.productService.getRiskRating(id));
    }

    @Override
    public CommonResp<List<FundManagerVO>> getFundManagerInfo(String id) {
        return CommonResp.success(this.productService.getFundManager(id));
    }

    @Override
    public CommonResp<FundRecordVO> getFundRecordInfo(String id) {
        return CommonResp.success(this.productService.getFundRecord(id));
    }

    @Override
    public CommonResp<FundCompanyVO> getFundCompanyInfo(String id) {
        return CommonResp.success(this.productService.getFundCompany(id));
    }

    @Override
    public CommonResp<List<ProductInfoVO>> getProductInfolist(ProductListReq req) {
        List<ProductInfoVO> productInfolist = this.productService.getProductInfolist(req);
        return CommonResp.success(productInfolist);
    }

    @Override
    public CommonResp<DynamicRetreatVO> getDynamicRetreatInfo(String id) {
        return CommonResp.success(this.productService.getDynamicRetreat(id));
    }

    @Override
    public CommonResp<List<Type>> getSimpleFundList(List<String> list) {
        return CommonResp.success(this.productService.getSimpleFundList(list));
    }

    @Override
    public CommonResp<ProductInfoVO> getPrivateDetail(String id) {
        if (StringUtils.isEmpty(id)) {
            return CommonResp.error(CommonResp.PARAMETER_INVALID_STATUS_CODE, CommonResp.PARAMETER_INVALID_MESSAGE);
        }
        return CommonResp.success(this.productService.getPrivateDetail(id));
    }

    @Override
    public CommonResp<List<TrackRecordVO>> getHistoryprofit(String id) {
        if (StringUtils.isEmpty(id)) {
            return CommonResp.error(CommonResp.PARAMETER_INVALID_STATUS_CODE, CommonResp.PARAMETER_INVALID_MESSAGE);
        }
        return CommonResp.success(this.productService.getHistoryprofit(id));
    }

    @Override
    public CommonResp<Page<TrackNetVO>> getPrivateFundTrackNetListInfo(String id, Pageable page) {
        if (StringUtils.isEmpty(id)) {
            return CommonResp.error(CommonResp.PARAMETER_INVALID_STATUS_CODE, CommonResp.PARAMETER_INVALID_MESSAGE);
        }
        return CommonResp.success(this.productService.getPrivateFundTrackNetList(id, page));
    }

    @Override
    public CommonResp<List<RiskRatingVO>> getPrivateFundRiskRatingInfo(String id) {
        if (StringUtils.isEmpty(id)) {
            return CommonResp.error(CommonResp.PARAMETER_INVALID_STATUS_CODE, CommonResp.PARAMETER_INVALID_MESSAGE);
        }
        return CommonResp.success(this.productService.getPrivateFundRiskRating(id));
    }

    @Override
    public CommonResp<List<ProductInfoVO>> getPrivateFundList(List<String> ids) {
        return CommonResp.success(this.productService.getPrivateFundList(ids));
    }

    @TanpuInterfaceLoginAuth
    @Override
    public CommonResp<List<FundSameResp>> getRemmendPrivateFundList(String fundId) {
        if (StringUtils.isEmpty(fundId)) {
            return CommonResp.error(CommonResp.PARAMETER_INVALID_STATUS_CODE, CommonResp.PARAMETER_INVALID_MESSAGE);
        }
        return CommonResp.success(this.productService.getRemmendPrivateFundList(fundId));
    }

    @Override
    public CommonResp<List<FundInfoSimpleListResp>> simpleList(List<String> idList) {
        return CommonResp.success(productService.getSimpleList(idList));
    }

    @Override
    public CommonResp<List<FundInfoSimpleListResp>> privateSimpleList(List<String> idList) {
        return CommonResp.success(productService.getPrivateSimpleList(idList));
    }

    @Override
    public CommonResp<FundCompanyVO> getPrivateFundCompanyInfo(String id, String ifaId, Pageable page) {
        return CommonResp.success(this.productPrivateService.getFundCompany(id, ifaId, page));
    }

    @Override
    public CommonResp<List<BonusRatioVO>> getPrivateBonusRatioInfo(String id) {
        return CommonResp.success(this.productPrivateService.getBonusRatio(id));
    }

    @Override
    public CommonResp<List<Type>> getSimplePrivateFundList(List<String> list) {
        return CommonResp.success(this.productPrivateService.getSimplePrivateFundList(list));
    }

    @Override
    public CommonResp<List<FundManagerVO>> getPrivateFundManagerInfo(String id, String ifaId) {
        return CommonResp.success(this.productPrivateService.getFundManager(id, ifaId));
    }


    @Override
    public CommonResp<List<FundIndexBasicResp>> fundIndexes() {
        return feignClientForPublicfund.fundIndexes();
    }

    @TanpuInterfaceLoginAuth
    @Override
    public CommonResp<List<FundSameResp>> querySamefund(String fundId) {
        if (StringUtils.isEmpty(fundId)) {
            return CommonResp.error(CommonResp.PARAMETER_INVALID_STATUS_CODE, CommonResp.PARAMETER_INVALID_MESSAGE);
        }
        return CommonResp.success(this.productService.querySamefund(fundId));
    }

    @Override
    public CommonResp<List<FundNavMessage>> importNetInfo(MultipartFile file, String fundId) {
        return this.productService.importNet(file, fundId);
    }

    @Override
    public CommonResp<List<FundNavMessage>> importNetCheckSaveInfo(IfaNetImportReq req) {
        return this.productService.importNetCheckSave(req);
    }

    @Override
    public CommonResp<Page<FundRankResp>> getFundRankInfo(FundRankReq req) {
        return CommonResp.success(this.productService.getFundRank(req));
    }

    @Override
    public CommonResp<Long> getFundRankCountInfo(FundRankReq req) {
        return CommonResp.success(this.productService.getFundRankCountInfo(req));
    }
}
