package com.tanpu.fund.entity.generator;

import java.math.BigDecimal;
import java.util.Date;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author: zhoupeng
 * <p>
 * =========================================
 * =========================================
 * ========                         ========
 * =======   ==========   =======    =======
 * ======        =====    ==   ====   ======
 * =====        =====     ==    ===    =====
 * =====       =====      ==   ===     =====
 * =====      =====       == ===       =====
 * ======    ==========   ==          ======
 * =======                           =======
 * =========================================
 * =========================================
 * <p>
 * @email: zhoupeng_08@163.com
 */

/**
 * 公司基本信息表
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class CompanyInfo {
    private String id;

    /**
     * 公司id
     */
    private String pCompanyId;

    /**
     * 公司中文全称
     */
    private String companyName;

    /**
     * 公司中文简称
     */
    private String companyShortName;

    /**
     * 基金管理人全称（英文）
     */
    private String companyEnglishName;

    /**
     * 公司类型：1-私募证券投资、2-公募基金公司、3-银行、4-证券公司、5-信托公司、6-审计机构，7-法律顾问，8-投资顾问，9-行政管理人,10-上市公司，11-期货公司，12-基金公司子公司，13工作室，14-私募股权投资，15-证券公司子公司，16-期货公司子公司，17-私募创业投资，-1-私募其他投资
     */
    private Integer companyType;

    /**
     * 组织机构代码
     */
    private String organizationNumber;

    /**
     * 公司成立日期
     */
    private Date establishDate;

    /**
     * 公司注册国家：1-中国大陆、2-香港、3-新加坡、4-开曼群岛、5-台湾、6-英属维尔京群岛BVI、-1-其他
     */
    private Integer domicileId;

    /**
     * 公司注册地址
     */
    private String companyAddress;

    /**
     * 办公地址
     */
    private String companyAddress2;

    /**
     * 城市
     */
    private String city;

    /**
     * 省
     */
    private String province;

    /**
     * 国家
     */
    private String country;

    /**
     * 注册城市
     */
    private String regCity;

    /**
     * 注册省
     */
    private String regProvince;

    /**
     * 注册国家
     */
    private String regCountry;

    /**
     * 联系电话
     */
    private String contactPhone;

    /**
     * 邮政编码
     */
    private String postCode;

    /**
     * 传真
     */
    private String fax;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 公司网址
     */
    private String website;

    /**
     * 公司注册资本，<量纲：万元>
     */
    private BigDecimal registeredCapital;

    /**
     * 是否有海外基金，0-否，1-是，-1-其他
     */
    private Integer offshoreFund;

    /**
     * 公司状态：1-运行；2-注销
     */
    private Integer companyStatus;

    /**
     * 公司注册资本货币单位：1-人民币，2-港币，3-美元，-1-其他
     */
    private Integer baseCurrencyCrc;

    /**
     * 备案编码
     */
    private String registerNumber;

    /**
     * 备案状态：0-未备案,1-备案注销,2-备案存续
     */
    private Integer registerStatus;

    /**
     * 备案日期
     */
    private Date registerDate;

    /**
     * 备案地址
     */
    private String registerNumberAddress;

    /**
     * 是否会员：1-是，0-否
     */
    private Byte isMember;

    /**
     * 入会时间
     */
    private Date joinDate;

    /**
     * 会员类型：1-普通会员、2-联席会员、3-观察会员、4-特别会员
     */
    private Integer memberType;

    /**
     * 管理基金主要类别（与中基协同步）
     */
    private String fundCategoryOri;

    /**
     * 业务类型
     */
    private String businessType;

    /**
     * 企业性质:1 中外合作企业 2中外合资企业 3内资企业 4境外机构 5外商独资企业 6政府机构
     */
    private Integer natureBusinessType;

    /**
     * 注册资本实缴比例
     */
    private BigDecimal capitalPaidRate;

    /**
     * 公司logo
     */
    private String logo;

    /**
     * 公司是否在前台可见
     */
    private Integer isvisible;

    /**
     * 实缴资本(万元)(人民币)
     */
    private BigDecimal paidCapital;

    /**
     * 公司资产规模 1:0-1亿 2:1-10亿 3:10-20亿 4:20-50亿 5:50-100亿 6:100亿以上
     */
    private Integer companyAssetSize;

    /**
     * 法人代表
     */
    private String legalRepresentative;

    /**
     * 是否认证 0:否 1:是
     */
    private Integer isQualify;

    /**
     * 法人从业资格获得方式
     */
    private String getQualifyMethod;

    /**
     * 员工人数
     */
    private Integer employeeCnts;

    /**
     * 信信息
     */
    private String integrityInfo;

    /**
     * 提示信息
     */
    private String specialTips;

    /**
     * 协会网站链接
     */
    private String amacLink;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 创建人
     */
    private String createBy;

    /**
     * 修改时间
     */
    private Date updateTime;

    /**
     * 修改人
     */
    private String updateBy;

    /**
     * 删除标识
     */
    private Integer deleteTag;

    /**
     * 公司简介
     */
    private String companyProfile;

    /**
     * 投资理念
     */
    private String philosopy;

    /**
     * 法人代表履历
     */
    private String representativeExperience;
}