package com.tanpu.fund.entity.generator;

import java.util.Date;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author: zhoupeng
 * <p>
 * =========================================
 * =========================================
 * ========                         ========
 * =======   ==========   =======    =======
 * ======        =====    ==   ====   ======
 * =====        =====     ==    ===    =====
 * =====       =====      ==   ===     =====
 * =====      =====       == ===       =====
 * ======    ==========   ==          ======
 * =======                           =======
 * =========================================
 * =========================================
 * <p>
 * @email: zhoupeng_08@163.com
 */

/**
 * 基金基本信息
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class FundInfo {
    /**
     * 基金id
     */
    private String id;

    /**
     * 父级产品ID
     */
    private String pFundId;

    /**
     * 基金中文全称
     */
    private String fundName;

    /**
     * 基金中文简称
     */
    private String fundShortName;

    /**
     * 基金形式：1-公司型，2-合伙型，3-契约型，-1-其他
     */
    private Integer fundStructure;

    /**
     * 私募基金类型：1-信托计划，2-有限合伙，3-券商资管，4-公募专户，5-单账户，6-证券投资基金，7-海外基金，8-期货资管，9-保险资管、10-创业投资基金、11-股权投资基金、12-银行理财、13-类固收信托、-1其他投资基金
     * 公募基金类型：1-混合型、2-债券型、3-定开债券、4-联接基金、5-货币型、6-债券指数、7-保本型、8-理财型、9-QDII、10-股票指数、11-QDII-指数、12-股票型、13-固定收益、14-分级杠杆、15-ETF-场内、16-QDII-ETF、17-债券创新-场内、18-封闭式
     */
    private Integer fundType;

    /**
     * 是否可预约 0:不可预约 1:可预约
     */
    private Integer type;

    /**
     * 募集方式：1-私募，2-公募
     */
    private Integer raiseType;

    /**
     * 基础货币,1-人民币，2-港币，3-美元，4-份，-1-其他
     */
    private Integer baseCurrency;

    /**
     * 成立日期
     */
    private Date inceptionDate;

    /**
     * 注册国家,1-中国大陆、2-香港、3-新加坡、4-开曼群岛、5-台湾、6-英属维尔京群岛BVI、-1-其他
     */
    private Integer domicile;

    /**
     * 指数id，以'IN'开头(后加36进制编码格式,不足8位长度左补零） 例：IN00000001
     */
    private String primaryBenchmarkId;

    /**
     * 封闭期，单位：月，-1：不确定，0：无封闭期
     */
    private Integer lockupPeriod;

    /**
     * 开放日
     */
    private String openDay;

    /**
     * 产品存续期，单位：月。-1，不确定，0，无固定期限，999999永续
     */
    private Integer duration;

    /**
     * 投资顾问id
     */
    private String advisorId;

    /**
     * 托管银行Id
     */
    private String custodianId;

    /**
     * 证券经纪人Id
     */
    private String brokerId;

    /**
     * 期货经纪人id
     */
    private String brokerFutureId;

    /**
     * 外包机构Id
     */
    private String liquidationAgencyId;

    /**
     * 基金管理公司Id
     */
    private String trustId;

    /**
     * 投资顾问Id
     */
    private String investmentConsultantId;

    /**
     * 行政管理人Id
     */
    private String administratorId;

    /**
     * 法律顾问Id
     */
    private String legalCounselId;

    /**
     * 审计机构
     */
    private String auditorId;

    /**
     * 净值披露频率 1:天 2：周 3：月 4：半月 5：季度
     */
    private Integer navFrequency;

    /**
     * 产品业绩披露标识：1-AAA，2-AA，3-A，4-A-，5-A+
     */
    private Integer performanceDisclosureMark;

    /**
     * 备案编码
     */
    private String registerNumber;

    /**
     * 备案日期
     */
    private Date registerDate;

    /**
     * 基金在前台是否可见:1-可见 0-不可见
     */
    private Integer isvisible;

    /**
     * 是否分级：1-分级，0-不分级;
     */
    private Integer istiered;

    /**
     * 是否参与排名，1-参与排名 0-不参与排名
     */
    private Integer isRanking;

    /**
     * 是否参与评级，1-参与评级 0-不参与评级
     */
    private Integer isRating;

    /**
     * 基金协会特别提示
     */
    private String specialTips;

    /**
     * 基金协会链接
     */
    private String amacUrl;

    /**
     * 净值来源说明：1-托管外包、2-信托券商官网、3-私募机构
     */
    private Integer navSourceType;

    /**
     * 基金描述
     */
    private String descInfo;

    /**
     * 融智策略分类，1-股票策略，2-宏观策略，3-管理期货，4-事件驱动，5-相对价值策略，6-固定收益策略，7-组合基金，8-复合策略，-1-其它策略
     */
    private Integer strategy;

    /**
     * 融智子策略分类:1010-主观多头 1020-股票多空 1030-量化多头 2010-宏观策略 3010-主观趋势 3020-主观套利 3030-量化趋势 3040-量化套利 3050-管理期货复合 4010-并购重组 4020-定向增发 4030-大宗交易 4040-事件驱动复合 5010-股票市场中性 5020-套利 5030-相对价值复合 6010-纯债策略 6020-强债策略 6030-固收复合 7010-MOM 7020-FOF 8010-主观多策略 8020-量化多策略 -1-其他策略'
     */
    private Integer substrategy;

    /**
     * 风险等级
     */
    private Integer riskLevel;

    private String createBy;

    private Date createTime;

    private String updateBy;

    private Date updateTime;

    /**
     * 数据来源 1:tanpu，2:私募排排
     */
    private Integer dataSources;

    /**
     * 0:待上架  1：已上架 2：已下架
     */
    private Integer status;

    /**
     * 删除标识 0:否 1:是
     */
    private Integer deleteTag;

    /**
     * 排序
     */
    private Integer sort;

    private String applyDay;

    private String redeemDay;

    /**
     * 券商资管产品特点
     */
    private String fundCharacteristic;

    /**
     * 基金投资范围
     */
    private String investmentScope;

    /**
     * 投资限制
     */
    private String investmentRestriction;

    /**
     * 投资理念
     */
    private String fundInvestmentPhilosophy;

    /**
     * 投资策略
     */
    private String fundStrategyDescription;

    /**
     * 组合目标
     */
    private String combineTarget;

    /**
     * 适合群体
     */
    private String fitGroup;

    /**
     * 组合点评
     */
    private String combineComment;

    /**
     * 调仓点评
     */
    private String transferComment;
}