package com.tanpu.fund.entity.generator;

import java.math.BigDecimal;
import java.util.Date;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author: zhoupeng
 * <p>
 * =========================================
 * =========================================
 * ========                         ========
 * =======   ==========   =======    =======
 * ======        =====    ==   ====   ======
 * =====        =====     ==    ===    =====
 * =====       =====      ==   ===     =====
 * =====      =====       == ===       =====
 * ======    ==========   ==          ======
 * =======                           =======
 * =========================================
 * =========================================
 * <p>
 * @email: zhoupeng_08@163.com
 */

/**
 * 基金费率
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class FundRateMapping {
    /**
     * 基金id(私募排排：'HF'开头(后加36进制编码格式,不足8位长度左补零） 例：HF00000001)
     */
    private String fundId;

    /**
     * 位面值
     */
    private String initialUnitValue;

    /**
     * 初始规模,<量纲：万>
     */
    private BigDecimal initialSize;

    /**
     * 最低认购额,<量纲：万> 券商资管产品量纲为<万元>
     */
    private BigDecimal minInvestmentShare;

    /**
     * 最低追加额,<量纲：万> 券商资管产品量纲为<万元>
     */
    private BigDecimal subsequentInvestmentShare;

    /**
     * 最高认购费，量纲<%>
     */
    private BigDecimal subscriptionFee;

    /**
     * 认（申）购费说明
     */
    private String subscriptionFeeNote;

    /**
     * 最高赎回费，量纲<%>
     */
    private BigDecimal redemptionFee;

    /**
     * 最高赎回费，量纲<%>
     */
    private String redemptionFeeNote;

    /**
     * 管理费计提周期，<量纲：月>
     */
    private String managementfeeDeductionFrequency;

    /**
     * 投资顾问管理费，<量纲：%>
     */
    private BigDecimal managementfeeConsult;

    /**
     * 受托人管理费，<量纲：%>
     */
    private BigDecimal managementfeeTrust;

    /**
     * 银行托管费，<量纲：%>
     */
    private BigDecimal managementfeeBank;

    /**
     * 最高绩效费，量纲<%>
     */
    private BigDecimal performanceFee;

    /**
     * 业绩报酬计提方式:0-未设 1-份额计提 2-净值计提 3-混合
     */
    private Integer performanceFeeDeductionMethod;

    /**
     * 其他费用说明
     */
    private String otherFeeNote;

    /**
     * 警戒线，<量纲：%>
     */
    private BigDecimal guardLine;

    /**
     * 止损线，<量纲：%>
     */
    private BigDecimal stopLossLine;

    /**
     * 保底收益率，<量纲：%>
     */
    private BigDecimal returnGuarantees;

    /**
     * 预计收益率
     */
    private BigDecimal expectedReturn;

    /**
     * 费前收益率（业绩提成前最低收益率），量纲<%>
     */
    private BigDecimal hurdleRate;

    /**
     * 融资杠杆比率
     */
    private String leverage;

    /**
     * 基金管理人参与资产比例
     */
    private String managerParticipateAsset;

    /**
     * 劣后级杠杆比率
     */
    private BigDecimal posterior;

    /**
     * 中间级杠杆比率
     */
    private BigDecimal intermediate;

    /**
     * 优先级杠杆比率
     */
    private BigDecimal priority;

    /**
     * 外包管理费，量纲<%>
     */
    private BigDecimal outsourcingFee;

    private String createBy;

    private Date createTime;

    private String updateBy;

    private Date updateTime;

    private Integer deleteTag;

    /**
     * 绩效费说明
     */
    private String performanceFeeNote;

    /**
     * 分红规则
     */
    private String dividendRule;
}