package com.tanpu.fund.service.impl;

import com.tanpu.fund.entity.generator.*;
import com.tanpu.fund.mapper.generator.FundCompanyInfoMapper;
import com.tanpu.fund.mapper.generator.FundCountMapper;
import com.tanpu.fund.mapper.generator.FundManagerMappingMapper;
import com.tanpu.fund.mapper.generator.FundPersonnelInfoMapper;
import com.tanpu.fund.service.ProductCommonService;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author: zyh
 */
@Service
public class ProductCommonServiceImpl implements ProductCommonService {

    @Resource
    private FundCountMapper fundCountMapper;
    @Resource
    private FundCompanyInfoMapper fundCompanyInfoMapper;
    @Resource
    private FundManagerMappingMapper fundManagerMappingMapper;
    @Resource
    private FundPersonnelInfoMapper fundPersonnelInfoMapper;

    @Override
    public FundCount getFundInfo(String fundId) {
        if (StringUtils.isEmpty(fundId)) {
            return null;
        }

        //查询基金统计信息
        FundCountExample fundCountExample = new FundCountExample();
        fundCountExample.createCriteria().andFundIdEqualTo(fundId);
        List<FundCount> fundCounts = fundCountMapper.selectByExample(fundCountExample);

        if (CollectionUtils.isNotEmpty(fundCounts)) {
            return fundCounts.get(0);
        }
        return null;
    }

    @Override
    public FundCompanyInfo getFundCompanyInfo(String companyId) {
        if (StringUtils.isEmpty(companyId)) {
            return null;
        }
        //查询基金公司
        FundCompanyInfoExample example = new FundCompanyInfoExample();
        example.createCriteria().andCompanyIdEqualTo(companyId);
        FundCompanyInfo fundCompanyInfo = fundCompanyInfoMapper.selectByPrimaryKey(companyId);

        return fundCompanyInfo;
    }

    @Override
    public List<FundPersonnelInfo> getFundManager(String fundId) {
        if (StringUtils.isEmpty(fundId)) {
            return null;
        }

        FundManagerMappingExample example = new FundManagerMappingExample();
        example.createCriteria().andFundIdEqualTo(fundId);
        List<FundManagerMapping> fundManagerMappings = fundManagerMappingMapper.selectByExample(example);
        if (CollectionUtils.isNotEmpty(fundManagerMappings)) {

            List<String> list = fundManagerMappings.stream().filter(item -> StringUtils.isNotEmpty(item.getFundManagerId()))
                    .map(FundManagerMapping::getFundManagerId).collect(Collectors.toList());

            FundPersonnelInfoExample fundPersonnelInfoExample = new FundPersonnelInfoExample();
            fundPersonnelInfoExample.createCriteria().andPersonnelIdIn(list);

            return fundPersonnelInfoMapper.selectByExample(fundPersonnelInfoExample);
        }
        return null;
    }

}
